"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.admiral.secret.v0.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountSystemSecretIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """account id"""
    secret_name: builtins.str
    """secret name"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "secret_name", b"secret_name"]) -> None: ...

global___AccountSystemSecretIdentifier = AccountSystemSecretIdentifier

class AccountSystemSecretDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> global___AccountSystemSecretSpec:
        """Secret spec"""
    def __init__(
        self,
        *,
        spec: global___AccountSystemSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> None: ...

global___AccountSystemSecretDefinition = AccountSystemSecretDefinition

class AccountSystemSecretSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_IDENTIFIER_FIELD_NUMBER: builtins.int
    ACCOUNT_SYSTEM_SECRET_FIELD_NUMBER: builtins.int
    @property
    def account_identifier(self) -> global___AccountSystemSecretIdentifier:
        """Secret identifier"""
    @property
    def account_system_secret(self) -> qwak.admiral.secret.v0.secret_pb2.SystemSecretSpec:
        """Secret"""
    def __init__(
        self,
        *,
        account_identifier: global___AccountSystemSecretIdentifier | None = ...,
        account_system_secret: qwak.admiral.secret.v0.secret_pb2.SystemSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_identifier", b"account_identifier", "account_system_secret", b"account_system_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_identifier", b"account_identifier", "account_system_secret", b"account_system_secret"]) -> None: ...

global___AccountSystemSecretSpec = AccountSystemSecretSpec
