"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PurchaseOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PurchaseOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PurchaseOption.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_PURCHASE_OPTION: _PurchaseOption.ValueType  # 0
    SPOT_PURCHASE_OPTION: _PurchaseOption.ValueType  # 1
    ONDEMAND_PURCHASE_OPTION: _PurchaseOption.ValueType  # 2

class PurchaseOption(_PurchaseOption, metaclass=_PurchaseOptionEnumTypeWrapper): ...

INVALID_PURCHASE_OPTION: PurchaseOption.ValueType  # 0
SPOT_PURCHASE_OPTION: PurchaseOption.ValueType  # 1
ONDEMAND_PURCHASE_OPTION: PurchaseOption.ValueType  # 2
global___PurchaseOption = PurchaseOption
