# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/projects/projects.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.models import models_pb2 as qwak_dot_models_dot_models__pb2
from _qwak_proto.qwak.projects import jfrog_project_spec_pb2 as qwak_dot_projects_dot_jfrog__project__spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cqwak/projects/projects.proto\x12\x18qwak.projects.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18qwak/models/models.proto\x1a&qwak/projects/jfrog_project_spec.proto\"\xad\x03\n\x0eProjectRequest\x12P\n\x16\x63reate_project_request\x18\x01 \x01(\x0b\x32..qwak.projects.management.CreateProjectRequestH\x00\x12P\n\x16\x64\x65lete_project_request\x18\x02 \x01(\x0b\x32..qwak.projects.management.DeleteProjectRequestH\x00\x12P\n\x16update_project_request\x18\x03 \x01(\x0b\x32..qwak.projects.management.UpdateProjectRequestH\x00\x12J\n\x13get_project_request\x18\x04 \x01(\x0b\x32+.qwak.projects.management.GetProjectRequestH\x00\x12N\n\x15list_projects_request\x18\x05 \x01(\x0b\x32-.qwak.projects.management.ListProjectsRequestH\x00\x42\t\n\x07request\"\x91\x01\n\x14\x43reateProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x1b\n\x13project_description\x18\x02 \x01(\t\x12\x46\n\njfrog_spec\x18\x03 \x01(\x0b\x32\x32.qwak.projects.management.ModelRepositoryJFrogSpec\"O\n\x15\x43reateProjectResponse\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.qwak.projects.management.ProjectSpec\"\x15\n\x13ListProjectsRequest\"O\n\x14ListProjectsResponse\x12\x37\n\x08projects\x18\x01 \x03(\x0b\x32%.qwak.projects.management.ProjectSpec\"=\n\x11GetProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\"H\n\x12GetProjectResponse\x12\x32\n\x07project\x18\x01 \x01(\x0b\x32!.qwak.projects.management.Project\"*\n\x14\x44\x65leteProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"%\n\x15\x44\x65leteProjectResponse\x12\x0c\n\x04info\x18\x01 \x01(\t\"{\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12O\n\x13project_spec_config\x18\x02 \x01(\x0b\x32\x32.qwak.projects.management.ProjectSpecConfiguration\"T\n\x15UpdateProjectResponse\x12;\n\x0cproject_spec\x18\x01 \x01(\x0b\x32%.qwak.projects.management.ProjectSpec\"\xac\x01\n\x07Project\x12\x33\n\x04spec\x18\x01 \x01(\x0b\x32%.qwak.projects.management.ProjectSpec\x12\x31\n\x06models\x18\x02 \x03(\x0b\x32\x1d.qwak.models.management.ModelB\x02\x18\x01\x12\x39\n\rmodels_briefs\x18\x03 \x03(\x0b\x32\".qwak.models.management.ModelBrief\"\xeb\x03\n\x0bProjectSpec\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\x12\x1b\n\x13project_description\x18\x03 \x01(\t\x12\x44\n\x0eproject_status\x18\x04 \x01(\x0e\x32,.qwak.projects.management.ProjectSpec.Status\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x34\n\x10last_modified_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x08 \x01(\t\x12\x14\n\x0cmodels_count\x18\t \x01(\x05\x12\x15\n\rmodels_active\x18\n \x01(\x05\x12N\n\x0ejfrog_settings\x18\x0b \x01(\x0b\x32\x36.qwak.projects.management.ModelRepositoryJFrogSettings\">\n\x06Status\x12\x0b\n\x07INVALID\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\r\n\tSUSPENDED\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\"Q\n\x18ProjectSpecConfiguration\x12\x18\n\x0cproject_name\x18\x01 \x01(\tB\x02\x18\x01\x12\x1b\n\x13project_description\x18\x02 \x01(\t\"\xb1\x02\n\x1cModelRepositoryJFrogSettings\x12S\n\x11pull_image_secret\x18\x01 \x01(\x0b\x32\x38.qwak.projects.management.ModelRepositoryPullImageSecret\x12[\n\x15jfrog_project_details\x18\x02 \x01(\x0b\x32<.qwak.projects.management.ModelRepositoryJFrogProjectDetails\x12_\n\x1ajfrog_repositories_details\x18\x03 \x01(\x0b\x32;.qwak.projects.management.ModelRepositoryArtifactoryDetails\"@\n\x1eModelRepositoryPullImageSecret\x12\x1e\n\x16pull_image_secret_name\x18\x01 \x01(\t\"?\n\"ModelRepositoryJFrogProjectDetails\x12\x19\n\x11jfrog_project_key\x18\x01 \x01(\t\"\xb7\x02\n!ModelRepositoryArtifactoryDetails\x12[\n\x1b\x61rtifact_repository_details\x18\x01 \x01(\x0b\x32\x36.qwak.projects.management.ArtifactoryRepositoryDetails\x12Z\n\x1a\x64\x61taset_repository_details\x18\x02 \x01(\x0b\x32\x36.qwak.projects.management.ArtifactoryRepositoryDetails\x12Y\n\x19\x64ocker_repository_details\x18\x03 \x01(\x0b\x32\x36.qwak.projects.management.ArtifactoryRepositoryDetails\"6\n\x1c\x41rtifactoryRepositoryDetails\x12\x16\n\x0erepository_key\x18\x01 \x01(\t2\xc9\x04\n\x19ProjectsManagementService\x12p\n\rCreateProject\x12..qwak.projects.management.CreateProjectRequest\x1a/.qwak.projects.management.CreateProjectResponse\x12m\n\x0cListProjects\x12-.qwak.projects.management.ListProjectsRequest\x1a..qwak.projects.management.ListProjectsResponse\x12g\n\nGetProject\x12+.qwak.projects.management.GetProjectRequest\x1a,.qwak.projects.management.GetProjectResponse\x12p\n\rDeleteProject\x12..qwak.projects.management.DeleteProjectRequest\x1a/.qwak.projects.management.DeleteProjectResponse\x12p\n\rUpdateProject\x12..qwak.projects.management.UpdateProjectRequest\x1a/.qwak.projects.management.UpdateProjectResponseB\'\n#com.qwak.ai.management.projects.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.projects.projects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.management.projects.apiP\001'
  _PROJECT.fields_by_name['models']._options = None
  _PROJECT.fields_by_name['models']._serialized_options = b'\030\001'
  _PROJECTSPECCONFIGURATION.fields_by_name['project_name']._options = None
  _PROJECTSPECCONFIGURATION.fields_by_name['project_name']._serialized_options = b'\030\001'
  _globals['_PROJECTREQUEST']._serialized_start=158
  _globals['_PROJECTREQUEST']._serialized_end=587
  _globals['_CREATEPROJECTREQUEST']._serialized_start=590
  _globals['_CREATEPROJECTREQUEST']._serialized_end=735
  _globals['_CREATEPROJECTRESPONSE']._serialized_start=737
  _globals['_CREATEPROJECTRESPONSE']._serialized_end=816
  _globals['_LISTPROJECTSREQUEST']._serialized_start=818
  _globals['_LISTPROJECTSREQUEST']._serialized_end=839
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=841
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=920
  _globals['_GETPROJECTREQUEST']._serialized_start=922
  _globals['_GETPROJECTREQUEST']._serialized_end=983
  _globals['_GETPROJECTRESPONSE']._serialized_start=985
  _globals['_GETPROJECTRESPONSE']._serialized_end=1057
  _globals['_DELETEPROJECTREQUEST']._serialized_start=1059
  _globals['_DELETEPROJECTREQUEST']._serialized_end=1101
  _globals['_DELETEPROJECTRESPONSE']._serialized_start=1103
  _globals['_DELETEPROJECTRESPONSE']._serialized_end=1140
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=1142
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1265
  _globals['_UPDATEPROJECTRESPONSE']._serialized_start=1267
  _globals['_UPDATEPROJECTRESPONSE']._serialized_end=1351
  _globals['_PROJECT']._serialized_start=1354
  _globals['_PROJECT']._serialized_end=1526
  _globals['_PROJECTSPEC']._serialized_start=1529
  _globals['_PROJECTSPEC']._serialized_end=2020
  _globals['_PROJECTSPEC_STATUS']._serialized_start=1958
  _globals['_PROJECTSPEC_STATUS']._serialized_end=2020
  _globals['_PROJECTSPECCONFIGURATION']._serialized_start=2022
  _globals['_PROJECTSPECCONFIGURATION']._serialized_end=2103
  _globals['_MODELREPOSITORYJFROGSETTINGS']._serialized_start=2106
  _globals['_MODELREPOSITORYJFROGSETTINGS']._serialized_end=2411
  _globals['_MODELREPOSITORYPULLIMAGESECRET']._serialized_start=2413
  _globals['_MODELREPOSITORYPULLIMAGESECRET']._serialized_end=2477
  _globals['_MODELREPOSITORYJFROGPROJECTDETAILS']._serialized_start=2479
  _globals['_MODELREPOSITORYJFROGPROJECTDETAILS']._serialized_end=2542
  _globals['_MODELREPOSITORYARTIFACTORYDETAILS']._serialized_start=2545
  _globals['_MODELREPOSITORYARTIFACTORYDETAILS']._serialized_end=2856
  _globals['_ARTIFACTORYREPOSITORYDETAILS']._serialized_start=2858
  _globals['_ARTIFACTORYREPOSITORYDETAILS']._serialized_end=2912
  _globals['_PROJECTSMANAGEMENTSERVICE']._serialized_start=2915
  _globals['_PROJECTSMANAGEMENTSERVICE']._serialized_end=3500
# @@protoc_insertion_point(module_scope)
