"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.prompt.v1.prompt.prompt_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreatePromptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    PROMPT_VERSION_SPEC_FIELD_NUMBER: builtins.int
    PROMPT_SPEC_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    @property
    def prompt_version_spec(self) -> qwak.prompt.v1.prompt.prompt_pb2.PromptVersionSpec:
        """Prompt Version spec"""
    @property
    def prompt_spec(self) -> qwak.prompt.v1.prompt.prompt_pb2.PromptSpec:
        """Prompt spec"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        prompt_version_spec: qwak.prompt.v1.prompt.prompt_pb2.PromptVersionSpec | None = ...,
        prompt_spec: qwak.prompt.v1.prompt.prompt_pb2.PromptSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_spec", b"prompt_spec", "prompt_version_spec", b"prompt_version_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name", "prompt_spec", b"prompt_spec", "prompt_version_spec", b"prompt_version_spec"]) -> None: ...

global___CreatePromptRequest = CreatePromptRequest

class CreatePromptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_FIELD_NUMBER: builtins.int
    @property
    def prompt(self) -> qwak.prompt.v1.prompt.prompt_pb2.Prompt:
        """Prompt definition"""
    def __init__(
        self,
        *,
        prompt: qwak.prompt.v1.prompt.prompt_pb2.Prompt | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt", b"prompt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt", b"prompt"]) -> None: ...

global___CreatePromptResponse = CreatePromptResponse

class CreatePromptVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    PROMPT_VERSION_SPEC_FIELD_NUMBER: builtins.int
    SET_DEFAULT_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    @property
    def prompt_version_spec(self) -> qwak.prompt.v1.prompt.prompt_pb2.PromptVersionSpec:
        """Prompt version spec"""
    set_default: builtins.bool
    """Set this version as default"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        prompt_version_spec: qwak.prompt.v1.prompt.prompt_pb2.PromptVersionSpec | None = ...,
        set_default: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_version_spec", b"prompt_version_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name", "prompt_version_spec", b"prompt_version_spec", "set_default", b"set_default"]) -> None: ...

global___CreatePromptVersionRequest = CreatePromptVersionRequest

class CreatePromptVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_VERSION_FIELD_NUMBER: builtins.int
    @property
    def prompt_version(self) -> qwak.prompt.v1.prompt.prompt_pb2.PromptVersion:
        """Prompt version definition"""
    def __init__(
        self,
        *,
        prompt_version: qwak.prompt.v1.prompt.prompt_pb2.PromptVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_version", b"prompt_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_version", b"prompt_version"]) -> None: ...

global___CreatePromptVersionResponse = CreatePromptVersionResponse

class UpdatePromptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    PROMPT_SPEC_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    @property
    def prompt_spec(self) -> qwak.prompt.v1.prompt.prompt_pb2.PromptSpec:
        """Prompt spec"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        prompt_spec: qwak.prompt.v1.prompt.prompt_pb2.PromptSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_spec", b"prompt_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name", "prompt_spec", b"prompt_spec"]) -> None: ...

global___UpdatePromptRequest = UpdatePromptRequest

class UpdatePromptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdatePromptResponse = UpdatePromptResponse

class GetPromptVersionByPromptNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    VERSION_NUMBER_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    version_number: builtins.int
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        version_number: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["optional_version_number", b"optional_version_number", "version_number", b"version_number"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["optional_version_number", b"optional_version_number", "prompt_name", b"prompt_name", "version_number", b"version_number"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_version_number", b"optional_version_number"]) -> typing_extensions.Literal["version_number"] | None: ...

global___GetPromptVersionByPromptNameRequest = GetPromptVersionByPromptNameRequest

class GetPromptVersionByPromptNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_VERSION_FIELD_NUMBER: builtins.int
    @property
    def prompt_version(self) -> qwak.prompt.v1.prompt.prompt_pb2.PromptVersion:
        """Prompt version definition"""
    def __init__(
        self,
        *,
        prompt_version: qwak.prompt.v1.prompt.prompt_pb2.PromptVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_version", b"prompt_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_version", b"prompt_version"]) -> None: ...

global___GetPromptVersionByPromptNameResponse = GetPromptVersionByPromptNameResponse

class GetPromptByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name"]) -> None: ...

global___GetPromptByNameRequest = GetPromptByNameRequest

class GetPromptByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_FIELD_NUMBER: builtins.int
    @property
    def prompt(self) -> qwak.prompt.v1.prompt.prompt_pb2.Prompt:
        """Prompt"""
    def __init__(
        self,
        *,
        prompt: qwak.prompt.v1.prompt.prompt_pb2.Prompt | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt", b"prompt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt", b"prompt"]) -> None: ...

global___GetPromptByNameResponse = GetPromptByNameResponse

class ListPromptsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListPromptsRequest = ListPromptsRequest

class ListPromptsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPTS_FIELD_NUMBER: builtins.int
    @property
    def prompts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.prompt.v1.prompt.prompt_pb2.Prompt]:
        """Prompts"""
    def __init__(
        self,
        *,
        prompts: collections.abc.Iterable[qwak.prompt.v1.prompt.prompt_pb2.Prompt] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompts", b"prompts"]) -> None: ...

global___ListPromptsResponse = ListPromptsResponse

class InitPaginationByPromptNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """prompt name"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name"]) -> None: ...

global___InitPaginationByPromptNameRequest = InitPaginationByPromptNameRequest

class InitPaginationByPromptNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    MAX_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """Number of versions found for this prompt at the time of querying.
    this is used mainly by the client to plan things like number of pages etc.
    """
    max_version_number: builtins.int
    """the current highest version number for this prompt. this is the anchor
    to use on subsequent requests if the caller wants to achieve
    a view of a static list
    """
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        max_version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_version_number", b"max_version_number", "record_count", b"record_count"]) -> None: ...

global___InitPaginationByPromptNameResponse = InitPaginationByPromptNameResponse

class ListPromptVersionsByPromptNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    MAX_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    page_size: builtins.int
    """The page size to use for the response - the number of results in the response
    is the minimum of the page_size and number of matching rows.
    - a negative value means all results will be returned (in that case page_number is ignored)
    """
    page_number: builtins.int
    """The page number to use"""
    max_version_number: builtins.int
    """The max version number to use as anchor - this is the value returned from InitPagination"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        max_version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_version_number", b"max_version_number", "page_number", b"page_number", "page_size", b"page_size", "prompt_name", b"prompt_name"]) -> None: ...

global___ListPromptVersionsByPromptNameRequest = ListPromptVersionsByPromptNameRequest

class ListPromptVersionsByPromptNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_VERSIONS_FIELD_NUMBER: builtins.int
    @property
    def prompt_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.prompt.v1.prompt.prompt_pb2.PromptVersion]:
        """Prompt versions"""
    def __init__(
        self,
        *,
        prompt_versions: collections.abc.Iterable[qwak.prompt.v1.prompt.prompt_pb2.PromptVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_versions", b"prompt_versions"]) -> None: ...

global___ListPromptVersionsByPromptNameResponse = ListPromptVersionsByPromptNameResponse

class DeletePromptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name"]) -> None: ...

global___DeletePromptRequest = DeletePromptRequest

class DeletePromptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeletePromptResponse = DeletePromptResponse

class DeletePromptVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    VERSION_NUMBER_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    version_number: builtins.int
    """Prompt version"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name", "version_number", b"version_number"]) -> None: ...

global___DeletePromptVersionRequest = DeletePromptVersionRequest

class DeletePromptVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeletePromptVersionResponse = DeletePromptVersionResponse

class SetDefaultPromptVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_NAME_FIELD_NUMBER: builtins.int
    VERSION_NUMBER_FIELD_NUMBER: builtins.int
    prompt_name: builtins.str
    """Prompt name"""
    version_number: builtins.int
    """Version number"""
    def __init__(
        self,
        *,
        prompt_name: builtins.str = ...,
        version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_name", b"prompt_name", "version_number", b"version_number"]) -> None: ...

global___SetDefaultPromptVersionRequest = SetDefaultPromptVersionRequest

class SetDefaultPromptVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetDefaultPromptVersionResponse = SetDefaultPromptVersionResponse

class ListPromptBriefsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListPromptBriefsRequest = ListPromptBriefsRequest

class ListPromptBriefsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_BRIEFS_FIELD_NUMBER: builtins.int
    @property
    def prompt_briefs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.prompt.v1.prompt.prompt_pb2.PromptBrief]:
        """Prompt briefs"""
    def __init__(
        self,
        *,
        prompt_briefs: collections.abc.Iterable[qwak.prompt.v1.prompt.prompt_pb2.PromptBrief] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_briefs", b"prompt_briefs"]) -> None: ...

global___ListPromptBriefsResponse = ListPromptBriefsResponse
