# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/cluster/v2/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.cluster.v2 import cluster_pb2 as qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/administration/cluster/v2/cluster_service.proto\x12\x1eqwak.administration.cluster.v2\x1a,qwak/administration/cluster/v2/cluster.proto\"h\n#CreateClusterCreationRequestRequest\x12\x41\n\x0c\x63luster_spec\x18\x01 \x01(\x0b\x32+.qwak.administration.cluster.v2.ClusterSpec\":\n$CreateClusterCreationRequestResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\",\n\x16GetClusterStateRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"^\n\x17GetClusterStateResponse\x12\x43\n\rcluster_state\x18\x01 \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterState\"\'\n\x11GetClusterRequest\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"Y\n\x12GetClusterResponse\x12\x43\n\rcluster_state\x18\x01 \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterState\"z\n!UpdateClusterConfigurationRequest\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x41\n\x0c\x63luster_spec\x18\x02 \x01(\x0b\x32+.qwak.administration.cluster.v2.ClusterSpec\"8\n\"UpdateClusterConfigurationResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"*\n\x14\x44\x65leteClusterRequest\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"+\n\x15\x44\x65leteClusterResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x15\n\x13ListClustersRequest\"P\n\x14ListClustersResponse\x12\x38\n\x07\x63luster\x18\x01 \x03(\x0b\x32\'.qwak.administration.cluster.v2.Cluster2\xd5\x06\n\x0e\x43lusterService\x12\xa9\x01\n\x1c\x43reateClusterCreationRequest\x12\x43.qwak.administration.cluster.v2.CreateClusterCreationRequestRequest\x1a\x44.qwak.administration.cluster.v2.CreateClusterCreationRequestResponse\x12\x82\x01\n\x0fGetClusterState\x12\x36.qwak.administration.cluster.v2.GetClusterStateRequest\x1a\x37.qwak.administration.cluster.v2.GetClusterStateResponse\x12\xa3\x01\n\x1aUpdateClusterConfiguration\x12\x41.qwak.administration.cluster.v2.UpdateClusterConfigurationRequest\x1a\x42.qwak.administration.cluster.v2.UpdateClusterConfigurationResponse\x12|\n\rDeleteCluster\x12\x34.qwak.administration.cluster.v2.DeleteClusterRequest\x1a\x35.qwak.administration.cluster.v2.DeleteClusterResponse\x12s\n\nGetCluster\x12\x31.qwak.administration.cluster.v2.GetClusterRequest\x1a\x32.qwak.administration.cluster.v2.GetClusterResponse\x12y\n\x0cListClusters\x12\x33.qwak.administration.cluster.v2.ListClustersRequest\x1a\x34.qwak.administration.cluster.v2.ListClustersResponseB\xb4\x01\n)com.qwak.ai.administration.api.cluster.v2P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.cluster.v2.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.cluster.v2P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2'
  _globals['_CREATECLUSTERCREATIONREQUESTREQUEST']._serialized_start=134
  _globals['_CREATECLUSTERCREATIONREQUESTREQUEST']._serialized_end=238
  _globals['_CREATECLUSTERCREATIONREQUESTRESPONSE']._serialized_start=240
  _globals['_CREATECLUSTERCREATIONREQUESTRESPONSE']._serialized_end=298
  _globals['_GETCLUSTERSTATEREQUEST']._serialized_start=300
  _globals['_GETCLUSTERSTATEREQUEST']._serialized_end=344
  _globals['_GETCLUSTERSTATERESPONSE']._serialized_start=346
  _globals['_GETCLUSTERSTATERESPONSE']._serialized_end=440
  _globals['_GETCLUSTERREQUEST']._serialized_start=442
  _globals['_GETCLUSTERREQUEST']._serialized_end=481
  _globals['_GETCLUSTERRESPONSE']._serialized_start=483
  _globals['_GETCLUSTERRESPONSE']._serialized_end=572
  _globals['_UPDATECLUSTERCONFIGURATIONREQUEST']._serialized_start=574
  _globals['_UPDATECLUSTERCONFIGURATIONREQUEST']._serialized_end=696
  _globals['_UPDATECLUSTERCONFIGURATIONRESPONSE']._serialized_start=698
  _globals['_UPDATECLUSTERCONFIGURATIONRESPONSE']._serialized_end=754
  _globals['_DELETECLUSTERREQUEST']._serialized_start=756
  _globals['_DELETECLUSTERREQUEST']._serialized_end=798
  _globals['_DELETECLUSTERRESPONSE']._serialized_start=800
  _globals['_DELETECLUSTERRESPONSE']._serialized_end=843
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=845
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=866
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=868
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=948
  _globals['_CLUSTERSERVICE']._serialized_start=951
  _globals['_CLUSTERSERVICE']._serialized_end=1804
# @@protoc_insertion_point(module_scope)
