# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/constructs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/fitness_service/constructs.proto\x12\x14qwak.fitness.service\"\xa2\x01\n\x0f\x42uildProperties\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x35\n\tmodel_uri\x18\x05 \x01(\x0b\x32\".qwak.fitness.service.ModelUriSpec\x12\x16\n\x0egpu_compatible\x18\x06 \x01(\x08\"\x8d\x01\n\x0cModelUriSpec\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x17\n\x0fgit_credentials\x18\x03 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x04 \x01(\t\x12\x11\n\tcommit_id\x18\x05 \x01(\t\x12\x10\n\x08main_dir\x18\x06 \x01(\t\"t\n\x08\x42uildEnv\x12\x33\n\ndocker_env\x18\x01 \x01(\x0b\x32\x1f.qwak.fitness.service.DockerEnv\x12\x33\n\npython_env\x18\x02 \x01(\x0b\x32\x1f.qwak.fitness.service.PythonEnv\"\x8a\x01\n\tDockerEnv\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x02 \x03(\t\x12\x10\n\x08no_cache\x18\x03 \x01(\x08\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x04 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x05 \x01(\t\"|\n\tPythonEnv\x12\x17\n\x0fgit_credentials\x18\x01 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x02 \x01(\t\x12\x18\n\x10qwak_sdk_version\x18\x03 \x01(\t\x12\x1c\n\x14qwak_sdk_extra_index\x18\x04 \x01(\t\"j\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12\x36\n\x0cmemory_units\x18\x03 \x01(\x0e\x32 .qwak.fitness.service.MemoryUnit\"\xaf\x01\n\x0cGpuResources\x12/\n\x08gpu_type\x18\x01 \x01(\x0e\x32\x1d.qwak.fitness.service.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\x12\x0b\n\x03\x63pu\x18\x03 \x01(\x02\x12\x15\n\rmemory_amount\x18\x04 \x01(\x05\x12\x36\n\x0cmemory_units\x18\x05 \x01(\x0e\x32 .qwak.fitness.service.MemoryUnit*7\n\nMemoryUnit\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x82\x03\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c\x12\x13\n\x0fNVIDIA_H100_NVL\x10\r\x12\x0e\n\nNVIDIA_A10\x10\x0e\x12\x13\n\x0fNVIDIA_H100_SXM\x10\x0f\x12\x14\n\x10NVIDIA_H100_40GB\x10\x10\x12\x14\n\x10NVIDIA_H100_80GB\x10\x11\x12\x0e\n\nNVIDIA_M60\x10\x12\x42#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.fitness_service.constructs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _globals['_MEMORYUNIT']._serialized_start=1043
  _globals['_MEMORYUNIT']._serialized_end=1098
  _globals['_GPUTYPE']._serialized_start=1101
  _globals['_GPUTYPE']._serialized_end=1487
  _globals['_BUILDPROPERTIES']._serialized_start=64
  _globals['_BUILDPROPERTIES']._serialized_end=226
  _globals['_MODELURISPEC']._serialized_start=229
  _globals['_MODELURISPEC']._serialized_end=370
  _globals['_BUILDENV']._serialized_start=372
  _globals['_BUILDENV']._serialized_end=488
  _globals['_DOCKERENV']._serialized_start=491
  _globals['_DOCKERENV']._serialized_end=629
  _globals['_PYTHONENV']._serialized_start=631
  _globals['_PYTHONENV']._serialized_end=755
  _globals['_CPURESOURCES']._serialized_start=757
  _globals['_CPURESOURCES']._serialized_end=863
  _globals['_GPURESOURCES']._serialized_start=866
  _globals['_GPURESOURCES']._serialized_end=1041
# @@protoc_insertion_point(module_scope)
