# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/account_membership_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.self_service.account.v0 import account_membership_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_account__membership__pb2
from _qwak_proto.qwak.self_service.user.v1 import user_pb2 as qwak_dot_self__service_dot_user_dot_v1_dot_user__pb2
from _qwak_proto.qwak.administration.v0.users import user_pb2 as qwak_dot_administration_dot_v0_dot_users_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=qwak/self_service/account/v0/account_membership_service.proto\x12\x1cqwak.self_service.account.v0\x1a\x35qwak/self_service/account/v0/account_membership.proto\x1a$qwak/self_service/user/v1/user.proto\x1a\'qwak/administration/v0/users/user.proto\" \n\x1eListAccountUserProfilesRequest\"`\n\x1fListAccountUserProfilesResponse\x12=\n\ruser_profiles\x18\x01 \x03(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"d\n\x15UpdateUserRoleRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x0c\x61\x63\x63ount_role\x18\x02 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\"V\n\x16UpdateUserRoleResponse\x12<\n\x0cuser_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"L\n%UpdateUserAssignedEnvironmentsRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0f\x65nvironment_ids\x18\x02 \x03(\t\"f\n&UpdateUserAssignedEnvironmentsResponse\x12<\n\x0cuser_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"*\n\x1cRemoveUserFromAccountRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1f\n\x1dRemoveUserFromAccountResponse\"Z\n\x1aInviteToJoinAccountRequest\x12<\n\x07options\x18\x01 \x03(\x0b\x32+.qwak.self_service.account.v0.InviteOptions\"n\n\x1bInviteToJoinAccountResponse\x12O\n\x0binvitations\x18\x01 \x03(\x0b\x32:.qwak.self_service.account.v0.JoiningInvitationDescription\"\x8a\x01\n\x17UpdateInvitationRequest\x12\x15\n\rinvitation_id\x18\x01 \x01(\t\x12?\n\x0c\x61\x63\x63ount_role\x18\x02 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\x12\x17\n\x0f\x65nvironment_ids\x18\x03 \x03(\t\"j\n\x18UpdateInvitationResponse\x12N\n\ninvitation\x18\x01 \x01(\x0b\x32:.qwak.self_service.account.v0.JoiningInvitationDescription\"0\n\x17\x41\x63\x63\x65ptInvitationRequest\x12\x15\n\rinvitation_id\x18\x01 \x01(\t\"\x1a\n\x18\x41\x63\x63\x65ptInvitationResponse\"7\n\x1e\x43\x61ncelJoiningInvitationRequest\x12\x15\n\rinvitation_id\x18\x01 \x01(\t\"!\n\x1f\x43\x61ncelJoiningInvitationResponse\"\x1f\n\x1dListAccountInvitationsRequest\"q\n\x1eListAccountInvitationsResponse\x12O\n\x0binvitations\x18\x01 \x03(\x0b\x32:.qwak.self_service.account.v0.JoiningInvitationDescription\"\x1c\n\x1aListUserInvitationsRequest\"n\n\x1bListUserInvitationsResponse\x12O\n\x0binvitations\x18\x01 \x03(\x0b\x32:.qwak.self_service.account.v0.JoiningInvitationDescription\"\x1c\n\x1aListUserMembershipsRequest\"\xbb\x01\n\x1bListUserMembershipsResponse\x12K\n\ruser_accounts\x18\x01 \x03(\x0b\x32\x34.qwak.self_service.account.v0.UserAccountDescription\x12O\n\x0binvitations\x18\x02 \x03(\x0b\x32:.qwak.self_service.account.v0.JoiningInvitationDescription2\xcf\x0c\n\x18\x41\x63\x63ountMembershipService\x12\x96\x01\n\x17ListAccountUserProfiles\x12<.qwak.self_service.account.v0.ListAccountUserProfilesRequest\x1a=.qwak.self_service.account.v0.ListAccountUserProfilesResponse\x12{\n\x0eUpdateUserRole\x12\x33.qwak.self_service.account.v0.UpdateUserRoleRequest\x1a\x34.qwak.self_service.account.v0.UpdateUserRoleResponse\x12\xab\x01\n\x1eUpdateUserAssignedEnvironments\x12\x43.qwak.self_service.account.v0.UpdateUserAssignedEnvironmentsRequest\x1a\x44.qwak.self_service.account.v0.UpdateUserAssignedEnvironmentsResponse\x12\x90\x01\n\x15RemoveUserFromAccount\x12:.qwak.self_service.account.v0.RemoveUserFromAccountRequest\x1a;.qwak.self_service.account.v0.RemoveUserFromAccountResponse\x12\x8a\x01\n\x13InviteToJoinAccount\x12\x38.qwak.self_service.account.v0.InviteToJoinAccountRequest\x1a\x39.qwak.self_service.account.v0.InviteToJoinAccountResponse\x12\x81\x01\n\x10UpdateInvitation\x12\x35.qwak.self_service.account.v0.UpdateInvitationRequest\x1a\x36.qwak.self_service.account.v0.UpdateInvitationResponse\x12\x81\x01\n\x10\x41\x63\x63\x65ptInvitation\x12\x35.qwak.self_service.account.v0.AcceptInvitationRequest\x1a\x36.qwak.self_service.account.v0.AcceptInvitationResponse\x12\x96\x01\n\x17\x43\x61ncelJoiningInvitation\x12<.qwak.self_service.account.v0.CancelJoiningInvitationRequest\x1a=.qwak.self_service.account.v0.CancelJoiningInvitationResponse\x12\x93\x01\n\x16ListAccountInvitations\x12;.qwak.self_service.account.v0.ListAccountInvitationsRequest\x1a<.qwak.self_service.account.v0.ListAccountInvitationsResponse\x12\x8a\x01\n\x13ListUserInvitations\x12\x38.qwak.self_service.account.v0.ListUserInvitationsRequest\x1a\x39.qwak.self_service.account.v0.ListUserInvitationsResponse\x12\x8a\x01\n\x13ListUserMemberships\x12\x38.qwak.self_service.account.v0.ListUserMembershipsRequest\x1a\x39.qwak.self_service.account.v0.ListUserMembershipsResponseB\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.self_service.account.v0.account_membership_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _globals['_LISTACCOUNTUSERPROFILESREQUEST']._serialized_start=229
  _globals['_LISTACCOUNTUSERPROFILESREQUEST']._serialized_end=261
  _globals['_LISTACCOUNTUSERPROFILESRESPONSE']._serialized_start=263
  _globals['_LISTACCOUNTUSERPROFILESRESPONSE']._serialized_end=359
  _globals['_UPDATEUSERROLEREQUEST']._serialized_start=361
  _globals['_UPDATEUSERROLEREQUEST']._serialized_end=461
  _globals['_UPDATEUSERROLERESPONSE']._serialized_start=463
  _globals['_UPDATEUSERROLERESPONSE']._serialized_end=549
  _globals['_UPDATEUSERASSIGNEDENVIRONMENTSREQUEST']._serialized_start=551
  _globals['_UPDATEUSERASSIGNEDENVIRONMENTSREQUEST']._serialized_end=627
  _globals['_UPDATEUSERASSIGNEDENVIRONMENTSRESPONSE']._serialized_start=629
  _globals['_UPDATEUSERASSIGNEDENVIRONMENTSRESPONSE']._serialized_end=731
  _globals['_REMOVEUSERFROMACCOUNTREQUEST']._serialized_start=733
  _globals['_REMOVEUSERFROMACCOUNTREQUEST']._serialized_end=775
  _globals['_REMOVEUSERFROMACCOUNTRESPONSE']._serialized_start=777
  _globals['_REMOVEUSERFROMACCOUNTRESPONSE']._serialized_end=808
  _globals['_INVITETOJOINACCOUNTREQUEST']._serialized_start=810
  _globals['_INVITETOJOINACCOUNTREQUEST']._serialized_end=900
  _globals['_INVITETOJOINACCOUNTRESPONSE']._serialized_start=902
  _globals['_INVITETOJOINACCOUNTRESPONSE']._serialized_end=1012
  _globals['_UPDATEINVITATIONREQUEST']._serialized_start=1015
  _globals['_UPDATEINVITATIONREQUEST']._serialized_end=1153
  _globals['_UPDATEINVITATIONRESPONSE']._serialized_start=1155
  _globals['_UPDATEINVITATIONRESPONSE']._serialized_end=1261
  _globals['_ACCEPTINVITATIONREQUEST']._serialized_start=1263
  _globals['_ACCEPTINVITATIONREQUEST']._serialized_end=1311
  _globals['_ACCEPTINVITATIONRESPONSE']._serialized_start=1313
  _globals['_ACCEPTINVITATIONRESPONSE']._serialized_end=1339
  _globals['_CANCELJOININGINVITATIONREQUEST']._serialized_start=1341
  _globals['_CANCELJOININGINVITATIONREQUEST']._serialized_end=1396
  _globals['_CANCELJOININGINVITATIONRESPONSE']._serialized_start=1398
  _globals['_CANCELJOININGINVITATIONRESPONSE']._serialized_end=1431
  _globals['_LISTACCOUNTINVITATIONSREQUEST']._serialized_start=1433
  _globals['_LISTACCOUNTINVITATIONSREQUEST']._serialized_end=1464
  _globals['_LISTACCOUNTINVITATIONSRESPONSE']._serialized_start=1466
  _globals['_LISTACCOUNTINVITATIONSRESPONSE']._serialized_end=1579
  _globals['_LISTUSERINVITATIONSREQUEST']._serialized_start=1581
  _globals['_LISTUSERINVITATIONSREQUEST']._serialized_end=1609
  _globals['_LISTUSERINVITATIONSRESPONSE']._serialized_start=1611
  _globals['_LISTUSERINVITATIONSRESPONSE']._serialized_end=1721
  _globals['_LISTUSERMEMBERSHIPSREQUEST']._serialized_start=1723
  _globals['_LISTUSERMEMBERSHIPSREQUEST']._serialized_end=1751
  _globals['_LISTUSERMEMBERSHIPSRESPONSE']._serialized_start=1754
  _globals['_LISTUSERMEMBERSHIPSRESPONSE']._serialized_end=1941
  _globals['_ACCOUNTMEMBERSHIPSERVICE']._serialized_start=1944
  _globals['_ACCOUNTMEMBERSHIPSERVICE']._serialized_end=3559
# @@protoc_insertion_point(module_scope)
