# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/traffic_mapping.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2qwak/kube_deployment_captain/traffic_mapping.proto\x12\x1cqwak.kube.deployment.captain\"\xd8\x01\n\x10VariationMapping\x12\'\n\x1fselected_variation_mapping_name\x18\x01 \x01(\t\x12\"\n\x1atraffic_request_timeout_ms\x18\x04 \x01(\x05\x12\x15\n\rdeployment_id\x18\x03 \x01(\t\x12P\n\x14traffic_mapping_spec\x18\x02 \x01(\x0b\x32\x30.qwak.kube.deployment.captain.TrafficMappingSpecH\x00\x42\x0e\n\x0cmapping_spec\";\n\x12TrafficMappingSpec\x12\x12\n\npercentage\x18\x01 \x01(\x05\x12\x11\n\tis_shadow\x18\x02 \x01(\x08\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.kube_deployment_captain.traffic_mapping_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _globals['_VARIATIONMAPPING']._serialized_start=85
  _globals['_VARIATIONMAPPING']._serialized_end=301
  _globals['_TRAFFICMAPPINGSPEC']._serialized_start=303
  _globals['_TRAFFICMAPPINGSPEC']._serialized_end=362
# @@protoc_insertion_point(module_scope)
