# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import feature_set_state_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__state__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/feature_store/features/feature_set_service.proto\x12\x1bqwak.feature.store.features\x1a\x33qwak/feature_store/features/feature_set_state.proto\x1a-qwak/feature_store/features/feature_set.proto\x1a\x33qwak/feature_store/features/feature_set_types.proto\"b\n\x19RegisterFeatureSetRequest\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\"Z\n\x1aRegisterFeatureSetResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"x\n\x17UpdateFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\"X\n\x18UpdateFeatureSetResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"2\n\x18GetFeatureSetByIdRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"Y\n\x19GetFeatureSetByIdResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"6\n\x1aGetFeatureSetByNameRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"[\n\x1bGetFeatureSetByNameResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\">\n#ListFeaturesetVersionsByNameRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"h\n$ListFeaturesetVersionsByNameResponse\x12@\n\x0b\x66\x65\x61turesets\x18\x01 \x03(\x0b\x32+.qwak.feature.store.features.FeaturesetInfo\"#\n!GetEnvToFeatureSetsMappingRequest\"\x91\x02\n\"GetEnvToFeatureSetsMappingResponse\x12\x7f\n\x1a\x65nv_to_feature_set_mapping\x18\x01 \x03(\x0b\x32[.qwak.feature.store.features.GetEnvToFeatureSetsMappingResponse.EnvToFeatureSetMappingEntry\x1aj\n\x1b\x45nvToFeatureSetMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetList:\x02\x38\x01\"1\n\x17\x44\x65leteFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteFeatureSetResponse\"\\\n\x1e\x44\x65leteFeaturesetVersionRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12!\n\x19\x66\x65\x61tureset_version_number\x18\x02 \x01(\x05\"!\n\x1f\x44\x65leteFeaturesetVersionResponse\"\x18\n\x16ListFeatureSetsRequest\"\\\n\x17ListFeatureSetsResponse\x12\x41\n\x10\x66\x65\x61ture_families\x18\x01 \x03(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"!\n\x1fListFeaturesetsByAccountRequest\"`\n ListFeaturesetsByAccountResponse\x12<\n\x0b\x66\x65\x61turesets\x18\x01 \x03(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"5\n\x19RunBatchFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"2\n\x1aRunBatchFeatureSetResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"p\n RunParquetBatchFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x18\n\x10parquet_location\x18\x02 \x01(\t\x12\x18\n\x10timestamp_column\x18\x03 \x01(\t\"#\n!RunParquetBatchFeatureSetResponse\"2\n\x16\x43reateUploadURLRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"x\n\x18\x43reateUploadURLRequestV1\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12\x43\n\x0etransformation\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.Transformation\"I\n.CreateRealTimeFeatureExtractorUploadURLRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"-\n\x17\x43reateUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\"\x89\x02\n\x1cUpdateFeatureSetStateRequest\x12m\n\x13\x66\x65\x61ture_names_state\x18\x01 \x03(\x0b\x32P.qwak.feature.store.features.UpdateFeatureSetStateRequest.FeatureNamesStateEntry\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x1a\x62\n\x16\x46\x65\x61tureNamesStateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qwak.feature.store.features.StateUpdate:\x02\x38\x01\"e\n\x0bStateUpdate\x12V\n\x13\x66\x65\x61ture_names_state\x18\x01 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState\"\x1f\n\x1dUpdateFeatureSetStateResponse\"K\n\x1fGetFeatureSetStateByNameRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\x03\"x\n GetFeatureSetStateByNameResponse\x12T\n\x11\x66\x65\x61ture_set_state\x18\x01 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState\"9\n\x1dGetFeatureSetStateByIdRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"^\n\x1eGetFeatureSetStateByIdResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"1\n\x16PauseFeaturesetRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\x19\n\x17PauseFeaturesetResponse\"2\n\x17ResumeFeaturesetRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\x1a\n\x18ResumeFeaturesetResponse\">\n#GetFeaturesetSchedulingStateRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"m\n$GetFeaturesetSchedulingStateResponse\x12\x45\n\x05state\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.FeaturesetSchedulingState\"_\n!SetActiveFeaturesetVersionRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12!\n\x19\x66\x65\x61tureset_version_number\x18\x02 \x01(\x05\"$\n\"SetActiveFeaturesetVersionResponse2\x81\x19\n\x11\x46\x65\x61tureSetService\x12\x85\x01\n\x12RegisterFeatureSet\x12\x36.qwak.feature.store.features.RegisterFeatureSetRequest\x1a\x37.qwak.feature.store.features.RegisterFeatureSetResponse\x12\x7f\n\x10UpdateFeatureSet\x12\x34.qwak.feature.store.features.UpdateFeatureSetRequest\x1a\x35.qwak.feature.store.features.UpdateFeatureSetResponse\x12\x82\x01\n\x11GetFeatureSetById\x12\x35.qwak.feature.store.features.GetFeatureSetByIdRequest\x1a\x36.qwak.feature.store.features.GetFeatureSetByIdResponse\x12\x88\x01\n\x13GetFeatureSetByName\x12\x37.qwak.feature.store.features.GetFeatureSetByNameRequest\x1a\x38.qwak.feature.store.features.GetFeatureSetByNameResponse\x12\xa3\x01\n\x1cListFeaturesetVersionsByName\x12@.qwak.feature.store.features.ListFeaturesetVersionsByNameRequest\x1a\x41.qwak.feature.store.features.ListFeaturesetVersionsByNameResponse\x12\x7f\n\x10\x44\x65leteFeatureSet\x12\x34.qwak.feature.store.features.DeleteFeatureSetRequest\x1a\x35.qwak.feature.store.features.DeleteFeatureSetResponse\x12\x94\x01\n\x17\x44\x65leteFeaturesetVersion\x12;.qwak.feature.store.features.DeleteFeaturesetVersionRequest\x1a<.qwak.feature.store.features.DeleteFeaturesetVersionResponse\x12|\n\x0fListFeatureSets\x12\x33.qwak.feature.store.features.ListFeatureSetsRequest\x1a\x34.qwak.feature.store.features.ListFeatureSetsResponse\x12\x97\x01\n\x18ListFeaturesetsByAccount\x12<.qwak.feature.store.features.ListFeaturesetsByAccountRequest\x1a=.qwak.feature.store.features.ListFeaturesetsByAccountResponse\x12\x85\x01\n\x12RunBatchFeatureSet\x12\x36.qwak.feature.store.features.RunBatchFeatureSetRequest\x1a\x37.qwak.feature.store.features.RunBatchFeatureSetResponse\x12\x9a\x01\n\x19RunParquetBatchFeatureSet\x12=.qwak.feature.store.features.RunParquetBatchFeatureSetRequest\x1a>.qwak.feature.store.features.RunParquetBatchFeatureSetResponse\x12\x81\x01\n\x0f\x43reateUploadURL\x12\x33.qwak.feature.store.features.CreateUploadURLRequest\x1a\x34.qwak.feature.store.features.CreateUploadURLResponse\"\x03\x88\x02\x01\x12\x80\x01\n\x11\x43reateUploadURLV1\x12\x35.qwak.feature.store.features.CreateUploadURLRequestV1\x1a\x34.qwak.feature.store.features.CreateUploadURLResponse\x12\xac\x01\n\'CreateRealTimeFeatureExtractorUploadURL\x12K.qwak.feature.store.features.CreateRealTimeFeatureExtractorUploadURLRequest\x1a\x34.qwak.feature.store.features.CreateUploadURLResponse\x12\x8e\x01\n\x15UpdateFeatureSetState\x12\x39.qwak.feature.store.features.UpdateFeatureSetStateRequest\x1a:.qwak.feature.store.features.UpdateFeatureSetStateResponse\x12\x97\x01\n\x18GetFeatureSetStateByName\x12<.qwak.feature.store.features.GetFeatureSetStateByNameRequest\x1a=.qwak.feature.store.features.GetFeatureSetStateByNameResponse\x12\x9d\x01\n\x1aGetEnvToFeatureSetsMapping\x12>.qwak.feature.store.features.GetEnvToFeatureSetsMappingRequest\x1a?.qwak.feature.store.features.GetEnvToFeatureSetsMappingResponse\x12\x91\x01\n\x16GetFeatureSetStateById\x12:.qwak.feature.store.features.GetFeatureSetStateByIdRequest\x1a;.qwak.feature.store.features.GetFeatureSetStateByIdResponse\x12|\n\x0fPauseFeatureset\x12\x33.qwak.feature.store.features.PauseFeaturesetRequest\x1a\x34.qwak.feature.store.features.PauseFeaturesetResponse\x12\x7f\n\x10ResumeFeatureset\x12\x34.qwak.feature.store.features.ResumeFeaturesetRequest\x1a\x35.qwak.feature.store.features.ResumeFeaturesetResponse\x12\xa3\x01\n\x1cGetFeaturesetSchedulingState\x12@.qwak.feature.store.features.GetFeaturesetSchedulingStateRequest\x1a\x41.qwak.feature.store.features.GetFeaturesetSchedulingStateResponse\x12\x9d\x01\n\x1aSetActiveFeaturesetVersion\x12>.qwak.feature.store.features.SetActiveFeaturesetVersionRequest\x1a?.qwak.feature.store.features.SetActiveFeaturesetVersionResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.feature_set_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _GETENVTOFEATURESETSMAPPINGRESPONSE_ENVTOFEATURESETMAPPINGENTRY._options = None
  _GETENVTOFEATURESETSMAPPINGRESPONSE_ENVTOFEATURESETMAPPINGENTRY._serialized_options = b'8\001'
  _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY._options = None
  _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY._serialized_options = b'8\001'
  _FEATURESETSERVICE.methods_by_name['CreateUploadURL']._options = None
  _FEATURESETSERVICE.methods_by_name['CreateUploadURL']._serialized_options = b'\210\002\001'
  _globals['_REGISTERFEATURESETREQUEST']._serialized_start=239
  _globals['_REGISTERFEATURESETREQUEST']._serialized_end=337
  _globals['_REGISTERFEATURESETRESPONSE']._serialized_start=339
  _globals['_REGISTERFEATURESETRESPONSE']._serialized_end=429
  _globals['_UPDATEFEATURESETREQUEST']._serialized_start=431
  _globals['_UPDATEFEATURESETREQUEST']._serialized_end=551
  _globals['_UPDATEFEATURESETRESPONSE']._serialized_start=553
  _globals['_UPDATEFEATURESETRESPONSE']._serialized_end=641
  _globals['_GETFEATURESETBYIDREQUEST']._serialized_start=643
  _globals['_GETFEATURESETBYIDREQUEST']._serialized_end=693
  _globals['_GETFEATURESETBYIDRESPONSE']._serialized_start=695
  _globals['_GETFEATURESETBYIDRESPONSE']._serialized_end=784
  _globals['_GETFEATURESETBYNAMEREQUEST']._serialized_start=786
  _globals['_GETFEATURESETBYNAMEREQUEST']._serialized_end=840
  _globals['_GETFEATURESETBYNAMERESPONSE']._serialized_start=842
  _globals['_GETFEATURESETBYNAMERESPONSE']._serialized_end=933
  _globals['_LISTFEATURESETVERSIONSBYNAMEREQUEST']._serialized_start=935
  _globals['_LISTFEATURESETVERSIONSBYNAMEREQUEST']._serialized_end=997
  _globals['_LISTFEATURESETVERSIONSBYNAMERESPONSE']._serialized_start=999
  _globals['_LISTFEATURESETVERSIONSBYNAMERESPONSE']._serialized_end=1103
  _globals['_GETENVTOFEATURESETSMAPPINGREQUEST']._serialized_start=1105
  _globals['_GETENVTOFEATURESETSMAPPINGREQUEST']._serialized_end=1140
  _globals['_GETENVTOFEATURESETSMAPPINGRESPONSE']._serialized_start=1143
  _globals['_GETENVTOFEATURESETSMAPPINGRESPONSE']._serialized_end=1416
  _globals['_GETENVTOFEATURESETSMAPPINGRESPONSE_ENVTOFEATURESETMAPPINGENTRY']._serialized_start=1310
  _globals['_GETENVTOFEATURESETSMAPPINGRESPONSE_ENVTOFEATURESETMAPPINGENTRY']._serialized_end=1416
  _globals['_DELETEFEATURESETREQUEST']._serialized_start=1418
  _globals['_DELETEFEATURESETREQUEST']._serialized_end=1467
  _globals['_DELETEFEATURESETRESPONSE']._serialized_start=1469
  _globals['_DELETEFEATURESETRESPONSE']._serialized_end=1495
  _globals['_DELETEFEATURESETVERSIONREQUEST']._serialized_start=1497
  _globals['_DELETEFEATURESETVERSIONREQUEST']._serialized_end=1589
  _globals['_DELETEFEATURESETVERSIONRESPONSE']._serialized_start=1591
  _globals['_DELETEFEATURESETVERSIONRESPONSE']._serialized_end=1624
  _globals['_LISTFEATURESETSREQUEST']._serialized_start=1626
  _globals['_LISTFEATURESETSREQUEST']._serialized_end=1650
  _globals['_LISTFEATURESETSRESPONSE']._serialized_start=1652
  _globals['_LISTFEATURESETSRESPONSE']._serialized_end=1744
  _globals['_LISTFEATURESETSBYACCOUNTREQUEST']._serialized_start=1746
  _globals['_LISTFEATURESETSBYACCOUNTREQUEST']._serialized_end=1779
  _globals['_LISTFEATURESETSBYACCOUNTRESPONSE']._serialized_start=1781
  _globals['_LISTFEATURESETSBYACCOUNTRESPONSE']._serialized_end=1877
  _globals['_RUNBATCHFEATURESETREQUEST']._serialized_start=1879
  _globals['_RUNBATCHFEATURESETREQUEST']._serialized_end=1932
  _globals['_RUNBATCHFEATURESETRESPONSE']._serialized_start=1934
  _globals['_RUNBATCHFEATURESETRESPONSE']._serialized_end=1984
  _globals['_RUNPARQUETBATCHFEATURESETREQUEST']._serialized_start=1986
  _globals['_RUNPARQUETBATCHFEATURESETREQUEST']._serialized_end=2098
  _globals['_RUNPARQUETBATCHFEATURESETRESPONSE']._serialized_start=2100
  _globals['_RUNPARQUETBATCHFEATURESETRESPONSE']._serialized_end=2135
  _globals['_CREATEUPLOADURLREQUEST']._serialized_start=2137
  _globals['_CREATEUPLOADURLREQUEST']._serialized_end=2187
  _globals['_CREATEUPLOADURLREQUESTV1']._serialized_start=2189
  _globals['_CREATEUPLOADURLREQUESTV1']._serialized_end=2309
  _globals['_CREATEREALTIMEFEATUREEXTRACTORUPLOADURLREQUEST']._serialized_start=2311
  _globals['_CREATEREALTIMEFEATUREEXTRACTORUPLOADURLREQUEST']._serialized_end=2384
  _globals['_CREATEUPLOADURLRESPONSE']._serialized_start=2386
  _globals['_CREATEUPLOADURLRESPONSE']._serialized_end=2431
  _globals['_UPDATEFEATURESETSTATEREQUEST']._serialized_start=2434
  _globals['_UPDATEFEATURESETSTATEREQUEST']._serialized_end=2699
  _globals['_UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY']._serialized_start=2601
  _globals['_UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY']._serialized_end=2699
  _globals['_STATEUPDATE']._serialized_start=2701
  _globals['_STATEUPDATE']._serialized_end=2802
  _globals['_UPDATEFEATURESETSTATERESPONSE']._serialized_start=2804
  _globals['_UPDATEFEATURESETSTATERESPONSE']._serialized_end=2835
  _globals['_GETFEATURESETSTATEBYNAMEREQUEST']._serialized_start=2837
  _globals['_GETFEATURESETSTATEBYNAMEREQUEST']._serialized_end=2912
  _globals['_GETFEATURESETSTATEBYNAMERESPONSE']._serialized_start=2914
  _globals['_GETFEATURESETSTATEBYNAMERESPONSE']._serialized_end=3034
  _globals['_GETFEATURESETSTATEBYIDREQUEST']._serialized_start=3036
  _globals['_GETFEATURESETSTATEBYIDREQUEST']._serialized_end=3093
  _globals['_GETFEATURESETSTATEBYIDRESPONSE']._serialized_start=3095
  _globals['_GETFEATURESETSTATEBYIDRESPONSE']._serialized_end=3189
  _globals['_PAUSEFEATURESETREQUEST']._serialized_start=3191
  _globals['_PAUSEFEATURESETREQUEST']._serialized_end=3240
  _globals['_PAUSEFEATURESETRESPONSE']._serialized_start=3242
  _globals['_PAUSEFEATURESETRESPONSE']._serialized_end=3267
  _globals['_RESUMEFEATURESETREQUEST']._serialized_start=3269
  _globals['_RESUMEFEATURESETREQUEST']._serialized_end=3319
  _globals['_RESUMEFEATURESETRESPONSE']._serialized_start=3321
  _globals['_RESUMEFEATURESETRESPONSE']._serialized_end=3347
  _globals['_GETFEATURESETSCHEDULINGSTATEREQUEST']._serialized_start=3349
  _globals['_GETFEATURESETSCHEDULINGSTATEREQUEST']._serialized_end=3411
  _globals['_GETFEATURESETSCHEDULINGSTATERESPONSE']._serialized_start=3413
  _globals['_GETFEATURESETSCHEDULINGSTATERESPONSE']._serialized_end=3522
  _globals['_SETACTIVEFEATURESETVERSIONREQUEST']._serialized_start=3524
  _globals['_SETACTIVEFEATURESETVERSIONREQUEST']._serialized_end=3619
  _globals['_SETACTIVEFEATURESETVERSIONRESPONSE']._serialized_start=3621
  _globals['_SETACTIVEFEATURESETVERSIONRESPONSE']._serialized_end=3657
  _globals['_FEATURESETSERVICE']._serialized_start=3660
  _globals['_FEATURESETSERVICE']._serialized_end=6861
# @@protoc_insertion_point(module_scope)
