"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.network_config_pb2
import qwak.administration.runtime_configuration.v0.runtime_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EnvironmentRuntimeConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> qwak.administration.runtime_configuration.v0.runtime_config_pb2.RuntimeConfiguration: ...
    @property
    def network_configuration(self) -> qwak.administration.runtime_configuration.v0.network_config_pb2.EnvironmentNetworkConfiguration: ...
    def __init__(
        self,
        *,
        runtime_configuration: qwak.administration.runtime_configuration.v0.runtime_config_pb2.RuntimeConfiguration | None = ...,
        network_configuration: qwak.administration.runtime_configuration.v0.network_config_pb2.EnvironmentNetworkConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "optional_runtime_config", b"optional_runtime_config", "runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "optional_runtime_config", b"optional_runtime_config", "runtime_configuration", b"runtime_configuration"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_runtime_config", b"optional_runtime_config"]) -> typing_extensions.Literal["runtime_configuration"] | None: ...

global___EnvironmentRuntimeConfigSpec = EnvironmentRuntimeConfigSpec
