# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/models/models_query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eqwak/models/models_query.proto\x12\x16qwak.models.management\"\x99\x01\n\nSortModels\x12\x31\n\x07sort_by\x18\x01 \x01(\x0e\x32\x1e.qwak.models.management.SortByH\x00\x12\x37\n\nsort_order\x18\x02 \x01(\x0e\x32!.qwak.models.management.SortOrderH\x01\x42\r\n\x0bsort_by_optB\x10\n\x0esort_order_opt\"\xc8\x01\n\x06\x46ilter\x12\x1e\n\x14model_name_substring\x18\x01 \x01(\tH\x00\x12\x19\n\x11model_group_names\x18\x02 \x03(\t\x12V\n\x17\x64\x65ployment_model_status\x18\x03 \x01(\x0e\x32\x33.qwak.models.management.DeploymentModelStatusFilterH\x01\x42\x0c\n\nsearch_optB\x1d\n\x1b\x64\x65ployment_model_status_opt\"<\n\x12PaginationMetadata\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x13\n\x0bnext_cursor\x18\x02 \x01(\t*J\n\x06SortBy\x12\x13\n\x0fSORT_BY_INVALID\x10\x00\x12\x10\n\x0cSORT_BY_NAME\x10\x01\x12\x19\n\x15SORT_BY_CREATION_DATE\x10\x02*L\n\tSortOrder\x12\x16\n\x12SORT_ORDER_INVALID\x10\x00\x12\x12\n\x0eSORT_ORDER_ASC\x10\x01\x12\x13\n\x0fSORT_ORDER_DESC\x10\x02*\xa5\x01\n\x1b\x44\x65ploymentModelStatusFilter\x12*\n&DEPLOYMENT_MODEL_STATUS_FILTER_INVALID\x10\x00\x12+\n\'DEPLOYMENT_MODEL_STATUS_FILTER_DEPLOYED\x10\x01\x12-\n)DEPLOYMENT_MODEL_STATUS_FILTER_UNDEPLOYED\x10\x02\x42\x36\n!com.qwak.ai.management.models.apiB\x0fModelQueryProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.models.models_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.models.apiB\017ModelQueryProtoP\001'
  _globals['_SORTBY']._serialized_start=479
  _globals['_SORTBY']._serialized_end=553
  _globals['_SORTORDER']._serialized_start=555
  _globals['_SORTORDER']._serialized_end=631
  _globals['_DEPLOYMENTMODELSTATUSFILTER']._serialized_start=634
  _globals['_DEPLOYMENTMODELSTATUSFILTER']._serialized_end=799
  _globals['_SORTMODELS']._serialized_start=59
  _globals['_SORTMODELS']._serialized_end=212
  _globals['_FILTER']._serialized_start=215
  _globals['_FILTER']._serialized_end=415
  _globals['_PAGINATIONMETADATA']._serialized_start=417
  _globals['_PAGINATIONMETADATA']._serialized_end=477
# @@protoc_insertion_point(module_scope)
