# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/features_operator/v1/features_operator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.features_operator.v1 import features_operator_pb2 as qwak_dot_features__operator_dot_v1_dot_features__operator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9qwak/features_operator/v1/features_operator_service.proto\x12\x19qwak.features_operator.v1\x1a\x31qwak/features_operator/v1/features_operator.proto\"]\n\x15\x42\x61seValidationRequest\x12\x18\n\x10proto_definition\x18\x01 \x01(\t\x12\x0f\n\x07imports\x18\x02 \x01(\t\x12\x19\n\x11number_of_samples\x18\x03 \x01(\x05\"^\n\x19ValidateDataSourceRequest\x12\x41\n\x07request\x18\x01 \x01(\x0b\x32\x30.qwak.features_operator.v1.BaseValidationRequest\"w\n\x19ValidateFeatureSetRequest\x12\x41\n\x07request\x18\x01 \x01(\x0b\x32\x30.qwak.features_operator.v1.BaseValidationRequest\x12\x17\n\x0fs3_udf_zip_path\x18\x02 \x01(\t\"\xc0\x01\n\x12ValidationResponse\x12P\n\x10success_response\x18\x01 \x01(\x0b\x32\x34.qwak.features_operator.v1.ValidationSuccessResponseH\x00\x12P\n\x10\x66\x61ilure_response\x18\x02 \x01(\x0b\x32\x34.qwak.features_operator.v1.ValidationFailureResponseH\x00\x42\x06\n\x04type2\x8f\x02\n\x17\x46\x65\x61turesOperatorService\x12y\n\x12ValidateDataSource\x12\x34.qwak.features_operator.v1.ValidateDataSourceRequest\x1a-.qwak.features_operator.v1.ValidationResponse\x12y\n\x12ValidateFeatureSet\x12\x34.qwak.features_operator.v1.ValidateFeatureSetRequest\x1a-.qwak.features_operator.v1.ValidationResponseB(\n$com.qwak.ai.features.operator.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.features_operator.v1.features_operator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.features.operator.api.v1P\001'
  _globals['_BASEVALIDATIONREQUEST']._serialized_start=139
  _globals['_BASEVALIDATIONREQUEST']._serialized_end=232
  _globals['_VALIDATEDATASOURCEREQUEST']._serialized_start=234
  _globals['_VALIDATEDATASOURCEREQUEST']._serialized_end=328
  _globals['_VALIDATEFEATURESETREQUEST']._serialized_start=330
  _globals['_VALIDATEFEATURESETREQUEST']._serialized_end=449
  _globals['_VALIDATIONRESPONSE']._serialized_start=452
  _globals['_VALIDATIONRESPONSE']._serialized_end=644
  _globals['_FEATURESOPERATORSERVICE']._serialized_start=647
  _globals['_FEATURESOPERATORSERVICE']._serialized_end=918
# @@protoc_insertion_point(module_scope)
