# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.admiral.secret.v0 import secret_service_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2


class SecretServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetEnvironmentSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SecretService/SetEnvironmentSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.SetEnvironmentSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.SetEnvironmentSecretResponse.FromString,
                )
        self.DeleteEnvironmentSecret = channel.unary_unary(
                '/qwak.admiral.secret.v0.SecretService/DeleteEnvironmentSecret',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.DeleteEnvironmentSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.DeleteEnvironmentSecretResponse.FromString,
                )
        self.ListAccountSecrets = channel.unary_unary(
                '/qwak.admiral.secret.v0.SecretService/ListAccountSecrets',
                request_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.ListAccountSecretsRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.ListAccountSecretsResponse.FromString,
                )


class SecretServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetEnvironmentSecret(self, request, context):
        """Set a value for a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironmentSecret(self, request, context):
        """Remove a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccountSecrets(self, request, context):
        """List account secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetEnvironmentSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEnvironmentSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.SetEnvironmentSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.SetEnvironmentSecretResponse.SerializeToString,
            ),
            'DeleteEnvironmentSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironmentSecret,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.DeleteEnvironmentSecretRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.DeleteEnvironmentSecretResponse.SerializeToString,
            ),
            'ListAccountSecrets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccountSecrets,
                    request_deserializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.ListAccountSecretsRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.ListAccountSecretsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.admiral.secret.v0.SecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetEnvironmentSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SecretService/SetEnvironmentSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.SetEnvironmentSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.SetEnvironmentSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironmentSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SecretService/DeleteEnvironmentSecret',
            qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.DeleteEnvironmentSecretRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.DeleteEnvironmentSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccountSecrets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.secret.v0.SecretService/ListAccountSecrets',
            qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.ListAccountSecretsRequest.SerializeToString,
            qwak_dot_admiral_dot_secret_dot_v0_dot_secret__service__pb2.ListAccountSecretsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
