# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/environment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.v0.environments import environment_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_environment__pb2
from _qwak_proto.qwak.administration.v0.environments import configuration_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_configuration__pb2
from _qwak_proto.qwak.administration.v0.environments import personalization_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_personalization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=qwak/administration/v0/environments/environment_service.proto\x12\x1fqwak.administration.environment\x1a\x35qwak/administration/v0/environments/environment.proto\x1a\x37qwak/administration/v0/environments/configuration.proto\x1a\x39qwak/administration/v0/environments/personalization.proto\"\x9f\x02\n\x18\x43reateEnvironmentRequest\x12\x18\n\x10\x65nvironment_name\x18\x01 \x01(\t\x12\x15\n\ttenant_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12T\n\rconfiguration\x18\x03 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\x12T\n\x0fpersonalization\x18\x05 \x01(\x0b\x32;.qwak.administration.environment.EnvironmentPersonalization\"b\n\x19\x43reateEnvironmentResponse\x12\x45\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment\"\x95\x01\n%UpdateEnvironmentConfigurationRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12T\n\rconfiguration\x18\x02 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\"(\n&UpdateEnvironmentConfigurationResponse\"\x97\x01\n\'UpdateEnvironmentPersonalizationRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12T\n\x0fpersonalization\x18\x02 \x01(\x0b\x32;.qwak.administration.environment.EnvironmentPersonalization\"*\n(UpdateEnvironmentPersonalizationResponse\"/\n\x15GetEnvironmentRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"_\n\x16GetEnvironmentResponse\x12\x45\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment\"I\n/GetEnvironmentApplicationUserCredentialsRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"\x8f\x01\n0GetEnvironmentApplicationUserCredentialsResponse\x12[\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32\x46.qwak.administration.environment.EnvironmentApplicationUserCredentials\"\xa6\x01\n/SetEnvironmentApplicationUserCredentialsRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12[\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x46.qwak.administration.environment.EnvironmentApplicationUserCredentials\"2\n0SetEnvironmentApplicationUserCredentialsResponse\"\xc8\x01\n\x17ListEnvironmentsRequest\x12O\n\x06\x66ilter\x18\x01 \x01(\x0b\x32?.qwak.administration.environment.ListEnvironmentsRequest.Filter\x1a\\\n\x06\x46ilter\x12R\n\x12\x65nvironment_status\x18\x01 \x01(\x0e\x32\x36.qwak.administration.environment.QwakEnvironmentStatus\"b\n\x18ListEnvironmentsResponse\x12\x46\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment2\xc1\t\n\x12\x45nvironmentService\x12\x8a\x01\n\x11\x43reateEnvironment\x12\x39.qwak.administration.environment.CreateEnvironmentRequest\x1a:.qwak.administration.environment.CreateEnvironmentResponse\x12\x81\x01\n\x0eGetEnvironment\x12\x36.qwak.administration.environment.GetEnvironmentRequest\x1a\x37.qwak.administration.environment.GetEnvironmentResponse\x12\xb1\x01\n\x1eUpdateEnvironmentConfiguration\x12\x46.qwak.administration.environment.UpdateEnvironmentConfigurationRequest\x1aG.qwak.administration.environment.UpdateEnvironmentConfigurationResponse\x12\xb7\x01\n UpdateEnvironmentPersonalization\x12H.qwak.administration.environment.UpdateEnvironmentPersonalizationRequest\x1aI.qwak.administration.environment.UpdateEnvironmentPersonalizationResponse\x12\x87\x01\n\x10ListEnvironments\x12\x38.qwak.administration.environment.ListEnvironmentsRequest\x1a\x39.qwak.administration.environment.ListEnvironmentsResponse\x12\xcf\x01\n(GetEnvironmentApplicationUserCredentials\x12P.qwak.administration.environment.GetEnvironmentApplicationUserCredentialsRequest\x1aQ.qwak.administration.environment.GetEnvironmentApplicationUserCredentialsResponse\x12\xcf\x01\n(SetEnvironmentApplicationUserCredentials\x12P.qwak.administration.environment.SetEnvironmentApplicationUserCredentialsRequest\x1aQ.qwak.administration.environment.SetEnvironmentApplicationUserCredentialsResponseB\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.v0.environments.environment_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _CREATEENVIRONMENTREQUEST.fields_by_name['tenant_id']._options = None
  _CREATEENVIRONMENTREQUEST.fields_by_name['tenant_id']._serialized_options = b'\030\001'
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_start=270
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_end=557
  _globals['_CREATEENVIRONMENTRESPONSE']._serialized_start=559
  _globals['_CREATEENVIRONMENTRESPONSE']._serialized_end=657
  _globals['_UPDATEENVIRONMENTCONFIGURATIONREQUEST']._serialized_start=660
  _globals['_UPDATEENVIRONMENTCONFIGURATIONREQUEST']._serialized_end=809
  _globals['_UPDATEENVIRONMENTCONFIGURATIONRESPONSE']._serialized_start=811
  _globals['_UPDATEENVIRONMENTCONFIGURATIONRESPONSE']._serialized_end=851
  _globals['_UPDATEENVIRONMENTPERSONALIZATIONREQUEST']._serialized_start=854
  _globals['_UPDATEENVIRONMENTPERSONALIZATIONREQUEST']._serialized_end=1005
  _globals['_UPDATEENVIRONMENTPERSONALIZATIONRESPONSE']._serialized_start=1007
  _globals['_UPDATEENVIRONMENTPERSONALIZATIONRESPONSE']._serialized_end=1049
  _globals['_GETENVIRONMENTREQUEST']._serialized_start=1051
  _globals['_GETENVIRONMENTREQUEST']._serialized_end=1098
  _globals['_GETENVIRONMENTRESPONSE']._serialized_start=1100
  _globals['_GETENVIRONMENTRESPONSE']._serialized_end=1195
  _globals['_GETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST']._serialized_start=1197
  _globals['_GETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST']._serialized_end=1270
  _globals['_GETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE']._serialized_start=1273
  _globals['_GETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE']._serialized_end=1416
  _globals['_SETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST']._serialized_start=1419
  _globals['_SETENVIRONMENTAPPLICATIONUSERCREDENTIALSREQUEST']._serialized_end=1585
  _globals['_SETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE']._serialized_start=1587
  _globals['_SETENVIRONMENTAPPLICATIONUSERCREDENTIALSRESPONSE']._serialized_end=1637
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_start=1640
  _globals['_LISTENVIRONMENTSREQUEST']._serialized_end=1840
  _globals['_LISTENVIRONMENTSREQUEST_FILTER']._serialized_start=1748
  _globals['_LISTENVIRONMENTSREQUEST_FILTER']._serialized_end=1840
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_start=1842
  _globals['_LISTENVIRONMENTSRESPONSE']._serialized_end=1940
  _globals['_ENVIRONMENTSERVICE']._serialized_start=1943
  _globals['_ENVIRONMENTSERVICE']._serialized_end=3160
# @@protoc_insertion_point(module_scope)
